@@ -12,15 +12,20 @@
 pub mod internal;
 
 use core::future::Future;
-use futures::{AsyncRead, AsyncBufRead, AsyncWrite};
+use crate::io;
 
 #[doc(inline)]
 pub use self::{
     decode::{
         Decode,
-        DecodeStatus,
+        PollDecodeStatus,
+        StartDecodeStatus,
+    },
+    encode::{
+        Encode,
+        PollEncodeStatus,
+        StartEncodeStatus,
     },
-    encode::Encode,
     format::{
         Format,
         FormatDecode,
@@ -62,15 +67,15 @@ pub trait AsyncSerialize: Encodable
     where
         Self: 'w,
         F: 'w + FormatSerialize,
-        W: 'w + AsyncWrite + Unpin,
+        W: 'w + io::AsyncWrite + Unpin,
     ;
 
     /// Attempt to serialize the type asynchronously for the indicated [format](Format)
-    /// via the provided [asynchronous writer](AsyncWrite).
+    /// via the provided [asynchronous writer](io::AsyncWrite).
     fn serialize<'w, F, W>(&'w self, format: &'w F, writer: &'w mut W) -> Self::Future<'w, F, W>
     where
         F: FormatSerialize,
-        W: AsyncWrite + Unpin,
+        W: io::AsyncWrite + Unpin,
     ;
 }
 
@@ -81,15 +86,15 @@ pub trait AsyncDeserialize: Decodable
     type Future<'r, F, R>: Future<Output=Result<Self, F::Error>> + Unpin
     where
         F: 'r + FormatDeserialize,
-        R: 'r + AsyncRead + AsyncBufRead + Unpin,
+        R: 'r + io::AsyncRead + io::AsyncBufRead + Unpin,
     ;
 
     /// Attempt to deserialize the type asynchronously for the indicated [format](Format)
-    /// via the provided [asynchronous reader](AsyncRead).
+    /// via the provided [asynchronous reader](io::AsyncRead).
     fn deserialize<'r, F, R>(format: &'r F, reader: &'r mut R) -> Self::Future<'r, F, R>
     where
         F: FormatDeserialize,
-        R: AsyncRead + AsyncBufRead + Unpin,
+        R: io::AsyncRead + io::AsyncBufRead + Unpin,
     ;
 }
 
