@@ -1,7 +1,7 @@
 use core::{marker::PhantomData, pin::Pin, task::{Context, Poll}};
-use futures::AsyncWrite;
-use crate::backend::{FormatEncode, FormatSerialize};
+use crate::backend::{self, FormatEncode, FormatSerialize};
 use crate::buffer::BufferEncode;
+use crate::io;
 
 /// A convenience structure that can serialize any implemenation of [BufferEncode].
 pub struct BufferEncoder<'w, F, W, Dta, Enc>
@@ -40,13 +40,17 @@ where
 impl<'w, F, W, Dta, Enc> core::future::Future for BufferEncoder<'w, F, W, Dta, Enc>
 where
     F: FormatSerialize,
-    W: AsyncWrite + Unpin,
+    W: io::AsyncWrite + Unpin,
     Enc: BufferEncode<Format=F, Data=Dta>,
 {
     type Output = Result<(), F::Error>;
 
     fn poll(mut self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
         let this = &mut *self;
-        this.encode.poll_encode_buffer(this.format, &mut this.writer, cx)
+        match this.encode.poll_encode_buffer(this.format, &mut this.writer, cx) {
+            backend::PollEncodeStatus::Fini     => Poll::Ready(Ok(())),
+            backend::PollEncodeStatus::Pending  => Poll::Pending,
+            backend::PollEncodeStatus::Error(e) => Poll::Ready(Err(e)),
+        }
     }
 }
\ No newline at end of file
