@@ -16,6 +16,9 @@ extern crate std;
 #[cfg(all(not(feature = "std"), feature = "alloc"))]
 extern crate alloc;
 
+#[macro_use]
+mod macros;
+
 /// Types and traits implemented by backend [formatters](backend::Format)
 pub mod backend;
 /// Helper modules for implementing buffered serialization primitives
@@ -23,6 +26,9 @@ pub mod buffer;
 /// Helper modules that may be externally useful
 pub mod util;
 
+/// Re-export of io related structures
+pub mod io;
+
 #[cfg_attr(docsrs, doc(cfg(feature = "derive")))]
 #[cfg(feature = "diny_derive")]
 pub use diny_derive::AsyncSerialization;
